#define F_CPU 1.0E6

#include <avr/io.h>
#include <util/delay.h>

/*
    Tt = 1 / ( FCPU / prescaler) (pokud prescaler používá FCPU)
    Tp = Tt * 255
    Ton = Tt * OCR
    Toff = Tp - T1

    Vrc = (OCR / 255) * 5v

    Tt = 1 / (1MHz / 1024) = 1 / 976.5625 = 0.001024 s
    Tp = 0.001024 * 255 = 0.26112 s
    Ton = 0.001024 * 64 = 0.065536 s
    Toff = 0.26112 - 0.065536 = 0.195584 s

    Tt = 1 / 1MHz = 1us
    Tp = 255 us
    Ton = 64 us
    Toff = 255 -64 = 191us

    Vrc = 64 / 255 * 5 = 1.25
*/

int main(void) {
    uint8_t pulses = 0;
              
    TCCR0A |= (1<<WGM00);           // korektní PWM
    TCCR0A |= (1<<COM0A1);          // práce s registerem OC0A dle módu PWM
    TCCR0B |= (1<<CS00);            // bez škálování

    DDRB |= (1 << PB2);             // nastaví OCR0A (PB2) pin jako vystupní

    while(1) {
        for(pulses = 0; pulses < 128; pulses++) {
            OCR0A = pulses;         // parametry vysílaného signálu
            _delay_ms(10);
        }

        for(pulses = 128; pulses > 0; pulses--) {
            OCR0A = pulses; 
            _delay_ms(10);
        }
    }
    return 1;
}
